@@ -809,6 +809,10 @@ void cridw_unlock(ULONG ulIndex, PCRIDDATA pInstance)
 void cridw_wait_for_event(ULONG ulIndex, PCRIDDATA pInstance)
 {
     POSDATA     pOsData = (POSDATA)pInstance->pOsData;
+
+#if LINUX_VERSION_CODE >= 0x020600
+    lock_kernel();
+#endif
     
     if (ulIndex == GET_PKT_WQ) {
     	interruptible_sleep_on(&pOsData->get_pkt_wq);
@@ -816,6 +820,10 @@ void cridw_wait_for_event(ULONG ulIndex, PCRIDDATA pInstance)
 	interruptible_sleep_on(&pOsData->slot_wq[ulIndex]);
     }
 
+#if LINUX_VERSION_CODE >= 0x020600
+    unlock_kernel();
+#endif
+
 } /* cridw_wait_for_event */
 
 
@@ -843,6 +851,10 @@ ULONG cridw_wait_for_event_timeout(ULONG ulIndex, ULONG ulTime, PCRIDDATA pInsta
 {
     POSDATA     pOsData = (POSDATA)pInstance->pOsData;
     ULONG retval = 0;
+
+#if LINUX_VERSION_CODE >= 0x020600
+    lock_kernel();
+#endif
     
     if (ulIndex == GET_PKT_WQ) {
     	retval = interruptible_sleep_on_timeout(&pOsData->get_pkt_wq, US_TO_TICKS(ulTime));
@@ -850,6 +862,9 @@ ULONG cridw_wait_for_event_timeout(ULONG ulIndex, ULONG ulTime, PCRIDDATA pInsta
 	retval = interruptible_sleep_on_timeout(&pOsData->slot_wq[ulIndex], US_TO_TICKS(ulTime));
     }
 
+#if LINUX_VERSION_CODE >= 0x020600
+    unlock_kernel();
+#endif
     return retval;
 
 } /* cridw_wait_for_event_timeout */
@@ -1631,11 +1646,13 @@ int cridw_log_evt(int log, int match, int num, void* entry)
    iml_interface_t cpqwEventHandler = (iml_interface_t)inter_module_get(EVENT_LOG_HANDLER);
 
    if (!cpqwEventHandler) {
+#if 0
 	if(!displayed) {
-//		printk(KERN_NOTICE "NOTICE: %s not registered. cpqevt module may not be loaded. Events will be not be logged.\n", 
-//				EVENT_LOG_HANDLER);
+		printk(KERN_NOTICE "NOTICE: %s not registered. cpqevt module may not be loaded. Events will be not be logged.\n", 
+				EVENT_LOG_HANDLER);
 		displayed = 1;
 	}
+#endif
    	return 0;
    }
 
@@ -1665,13 +1682,14 @@ int cridw_set_evthnd(void* evthnd)
 
    #define EVENT_CALLBACK "callCridLog"
    void** callback = (void**)inter_module_get(EVENT_CALLBACK);
-
    if (!callback) {
+#if 0
 	if(!displayed) {
-//		printk(KERN_NOTICE "NOTICE: %s not registered. cpqevt module may not be loaded. No events will be received.\n", 
-//				EVENT_CALLBACK);
+		printk(KERN_NOTICE "NOTICE: %s not registered. cpqevt module may not be loaded. No events will be received.\n", 
+				EVENT_CALLBACK);
 		displayed = 1;
 	}
+#endif
    	return 0;
    }
 
